@@ -1,4 +1,5 @@
-from . import pyhackrf_info  # noqa F401
-from . import pyhackrf_sweep  # noqa F401
 from . import pyhackrf_operacake  # noqa F401
-from .__android import get_device  # noqa F401
+from . import pyhackrf_transfer  # noqa F401
+from . import pyhackrf_sweep  # noqa F401
+from . import pyhackrf_info  # noqa F401
+from . import utils  # noqa F401
